#
# spec file for package perl-URI
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name URI
Name:           perl-URI
Version:        5.290.0
Release:        1.1
# 5.29 -> normalize -> 5.290.0
%define cpan_version 5.29
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Uniform Resource Identifiers (absolute and relative)
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/O/OA/OALDERS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(MIME::Base32)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Test::Needs)
BuildRequires:  perl(Test::Warnings)
BuildRequires:  perl(parent)
Requires:       perl(MIME::Base32)
Requires:       perl(parent)
Provides:       perl(URI) = %{version}
Provides:       perl(URI::Escape) = %{version}
Provides:       perl(URI::Heuristic) = %{version}
Provides:       perl(URI::IRI) = %{version}
Provides:       perl(URI::QueryParam) = %{version}
Provides:       perl(URI::Split) = %{version}
Provides:       perl(URI::URL) = %{version}
Provides:       perl(URI::WithBase) = %{version}
Provides:       perl(URI::data) = %{version}
Provides:       perl(URI::file) = %{version}
Provides:       perl(URI::file::Base) = %{version}
Provides:       perl(URI::file::FAT) = %{version}
Provides:       perl(URI::file::Mac) = %{version}
Provides:       perl(URI::file::OS2) = %{version}
Provides:       perl(URI::file::QNX) = %{version}
Provides:       perl(URI::file::Unix) = %{version}
Provides:       perl(URI::file::Win32) = %{version}
Provides:       perl(URI::ftp) = %{version}
Provides:       perl(URI::geo) = %{version}
Provides:       perl(URI::gopher) = %{version}
Provides:       perl(URI::http) = %{version}
Provides:       perl(URI::https) = %{version}
Provides:       perl(URI::icap) = %{version}
Provides:       perl(URI::icaps) = %{version}
Provides:       perl(URI::ldap) = %{version}
Provides:       perl(URI::ldapi) = %{version}
Provides:       perl(URI::ldaps) = %{version}
Provides:       perl(URI::mailto) = %{version}
Provides:       perl(URI::mms) = %{version}
Provides:       perl(URI::news) = %{version}
Provides:       perl(URI::nntp) = %{version}
Provides:       perl(URI::nntps) = %{version}
Provides:       perl(URI::otpauth) = %{version}
Provides:       perl(URI::pop) = %{version}
Provides:       perl(URI::rlogin) = %{version}
Provides:       perl(URI::rsync) = %{version}
Provides:       perl(URI::rtsp) = %{version}
Provides:       perl(URI::rtspu) = %{version}
Provides:       perl(URI::sftp) = %{version}
Provides:       perl(URI::sip) = %{version}
Provides:       perl(URI::sips) = %{version}
Provides:       perl(URI::snews) = %{version}
Provides:       perl(URI::ssh) = %{version}
Provides:       perl(URI::telnet) = %{version}
Provides:       perl(URI::tn3270) = %{version}
Provides:       perl(URI::urn) = %{version}
Provides:       perl(URI::urn::isbn) = %{version}
Provides:       perl(URI::urn::oid) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module implements the 'URI' class. Objects of this class represent
"Uniform Resource Identifier references" as specified in RFC 2396 (and
updated by RFC 2732).

A Uniform Resource Identifier is a compact string of characters that
identifies an abstract or physical resource. A Uniform Resource Identifier
can be further classified as either a Uniform Resource Locator (URL) or a
Uniform Resource Name (URN). The distinction between URL and URN does not
matter to the 'URI' class interface. A "URI-reference" is a URI that may
have additional information attached in the form of a fragment identifier.

An absolute URI reference consists of three parts: a _scheme_, a
_scheme-specific part_ and a _fragment_ identifier. A subset of URI
references share a common syntax for hierarchical namespaces. For these,
the scheme-specific part is further broken down into _authority_, _path_
and _query_ components. These URIs can also take the form of relative URI
references, where the scheme (and usually also the authority) component is
missing, but implied by the context of the URI reference. The three forms
of URI reference syntax are summarized as follows:

  <scheme>:<scheme-specific-part>#<fragment>
  <scheme>://<authority><path>?<query>#<fragment>
  <path>?<query>#<fragment>

The components into which a URI reference can be divided depend on the
_scheme_. The 'URI' class provides methods to get and set the individual
components. The methods available for a specific 'URI' object depend on the
scheme.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md README uri-test
%license LICENSE

%changelog
* Fri Sep  6 2024 Tina Müller <timueller+perl@suse.de>
- updated to 5.290.0 (5.29)
  see /usr/share/doc/packages/perl-URI/Changes
  5.29      2024-09-05 16:09:30Z
  - Add otpauth URI (GH#145) (david-dick)
* Wed Mar 27 2024 Tina Müller <timueller+perl@suse.de>
- updated to 5.28
  see /usr/share/doc/packages/perl-URI/Changes
  5.28      2024-03-27 01:49:44Z
  - Using Scalar::Util::reftype instead of just ref(), but mindful this time
    about definedness to avoid warnings (GH#140) (Jacques Deguest)
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Sat Feb 10 2024 Tina Müller <timueller+perl@suse.de>
- updated to 5.27
  see /usr/share/doc/packages/perl-URI/Changes
  5.27      2024-02-09 15:01:24Z
  - Add missing NAME section to POD of URI::geo (GH#142) (gregor herrmann)
  5.26      2024-02-02 19:04:40Z
  - Add URI::geo (GH#141) (david-dick)
  5.25      2024-01-27 16:11:41Z
  - cache scheme so it never attempt to load it again (GH#55) (mschae94)
  5.24      2024-01-26 04:36:32Z
  - Really revert "use Scalar::Util::reftype instead of ref to check for
    ARRAY" (GH#136) (Olaf Alders)
  5.23      2024-01-25 21:02:18Z
  - Revert the reftype change introduced in 5.22 as it causes warnings.
    (GH#134) (Olaf Alders)
  5.22      2024-01-25 15:22:54Z
  - Use Scalar::Util::reftype instead of ref to check for ARRAY (GH#132)
    (Jacques Deguest)
* Thu Aug 24 2023 Tina Müller <timueller+perl@suse.de>
- updated to 5.21
  see /usr/share/doc/packages/perl-URI/Changes
  5.21      2023-08-23 16:02:14Z
  - Fix version declarations in icap.pm and icaps.pm (GH#131) (Olaf Alders)
  5.20      2023-08-23 14:13:23Z
  - Remove Shebang and Taint from all tests.
  - Fix t/query.t to get rid of a warning about join() on
    array with undef
  - Add icap and icaps URIs (GH#130) (david-dick)
* Mon May  1 2023 Tina Müller <timueller+perl@suse.de>
- updated to 5.19
  see /usr/share/doc/packages/perl-URI/Changes
  5.19      2023-04-30 16:15:58Z
  - Form parameters without values are now represented by undef (GH#65)
    (Gianni Ceccarelli)
  5.18      2023-04-29 16:08:14Z
  - Add a GH workflow to test LWP::Curl (GH#116) (Olaf Alders)
  - Add documentation examples for the host() and ihost() methods (GH#28)
    (Sebastian Willing)
  - Remove colon from username:password if there is no password (GH#31)
    (David E. Wheeler, Joenio Marques da Costa, Julien Fiegehenn)
  - Prefix private methods with _ in URI::_punycode (GH#47) (David E Wheeler)
* Thu Nov  3 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.17
  see /usr/share/doc/packages/perl-URI/Changes
  5.17      2022-11-02 17:03:48Z
  - Updated RFC references in the pod documentation for URI::file (GH#117)
    (Håkon Hgland)
  - Fix SIP URI encoder/decoder (GH#118) (ryankereliuk)
* Thu Oct 13 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.16
  see /usr/share/doc/packages/perl-URI/Changes
  5.16      2022-10-12 13:10:40Z
  - Merge the methods from URI::QueryParam into URI, so they are always
    available (GH#114) (Graham Knop)
  5.15      2022-10-11 14:48:28Z
  - Teach uri_escape to accept a Regexp object as the characters to escape
    as an alternative to a character class. (GH#113) (Graham Knop)
  5.14      2022-10-10 20:37:57Z
  - Fix uri_escape allowing \w style character classes in its character set
    parameter (GH#112) (Graham Knop)
  5.13      2022-10-06 16:46:32Z
  - Regression test added for a previous bug (5.11) in URI::file (Perlbotics).
    file() method of URI::file can return the current working directory
    instead of the properly unescaped path. (GH#106) (Perlbotics)
  - Replace "Test" with "Test::More" (GH#107) (James Raspass)
  - Replace raw TAP printing with "Test::More" (GH#108) (James Raspass)
  - Apply perlimports to tests (GH#110) (Olaf Alders)
  - Improve escaping of unwanted characters (GH#78) (Branislav Zahradnk)
* Mon Jul 11 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.12
  see /usr/share/doc/packages/perl-URI/Changes
  5.12      2022-07-10 23:48:50Z
  - Fix an issue where i.e. 'file:///tmp/###' was not properly escaped.
    A non-existing authority part was accidentally processed.
    Details: https://github.com/libwww-perl/URI/issues/102
    (GH#102) (Perlbotics)
  - Reverts to previous behavior (5.10) for 'mailto:' scheme for
    escaping square brackets.
  5.11      2022-07-04 20:53:38Z
  - Fix some typos in URI::file (GH#94) (Olaf Alders)
  - Escape square brackets in path (GH#100) (Perlbotics)
  - Fix storable.t (GH#97) (Shoichi Kaji)
* Tue Oct 26 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.10
  see /usr/share/doc/packages/perl-URI/Changes
  5.10      2021-10-25 20:58:42Z
  - Remove Authority section from dist.ini (GH#86) (Olaf Alders)
  - Make URI::mailto parse subaddresses with + sign correctly (GH#89) (Julien Fiegehenn)
* Thu Mar  4 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.09
  see /usr/share/doc/packages/perl-URI/Changes
  5.09      2021-03-03 15:16:47Z
  - Update Business::ISBN version requirements (GH#85) (brian d foy and Olaf
    Alders)
* Mon Mar  1 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.08
  see /usr/share/doc/packages/perl-URI/Changes
  5.08      2021-02-28 18:08:32Z
  - added URI::nntps (GH#82)
* Sat Jan 30 2021 Dirk Müller <dmueller@suse.com>
- update to 5.07:
  s/perl.com/example.com/ in examples and tests
* Fri Jan 15 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.06
  see /usr/share/doc/packages/perl-URI/Changes
  5.06      2021-01-14 16:01:13Z
  - Tidy import statements (GH#80) (Olaf Alders)
* Thu Oct 22 2020 Tina Müller <timueller+perl@suse.de>
- updated to 5.05
  see /usr/share/doc/packages/perl-URI/Changes
  5.05      2020-10-21 13:00:44Z
  - Bump all versions to 5.05 in order to remove various version mismatches.
    (GH #77) (Olaf Alders)
  - Add a simple test case for an ipv6 host (GH#66) (Olaf Alders)
* Fri Jan 11 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.76
  see /usr/share/doc/packages/perl-URI/Changes
  1.76      2019-01-09 16:59:54Z
  - Revert changes introduced in 1.75
* Wed Jan  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.75
  see /usr/share/doc/packages/perl-URI/Changes
  1.75      2019-01-08 19:45:38Z
  - $uri->canonical unconditionally returns a clone (GH#58) (Dorian Taylor)
* Tue Apr 24 2018 coolo@suse.com
- updated to 1.74
  see /usr/share/doc/packages/perl-URI/Changes
  1.74      2018-04-22 12:30:44Z
  - avoid 'uninitialized' warning in URI::File when host has no domain name
    set (PR#53, thanks Shoichi Kaji!)
* Wed Jan 10 2018 coolo@suse.com
- updated to 1.73
  see /usr/share/doc/packages/perl-URI/Changes
  1.73      2018-01-09 06:42:51Z
  - Update documentation for URI::_punycode (GH Issue #45)
* Thu Jul 27 2017 coolo@suse.com
- updated to 1.72
  see /usr/share/doc/packages/perl-URI/Changes
  1.72      2017-07-25
  - Convert the dist to Dist::Zilla for authoring.
  - Remove recommendation of Business::ISBN as urn/isbn.pm is deprecated
  - Use Test::Needs instead of raw eval in urn-isbn.t
* Wed Jan 13 2016 coolo@suse.com
- updated to 1.71
  see /usr/share/doc/packages/perl-URI/Changes
  2016-01-08   Karen Etheridge <ether@cpan.org>
    Release 1.71
    No changes since 1.70_001
  2015-12-29   Karen Etheridge <ether@cpan.org>
    Release 1.70_001
    Kaitlyn Parkhurst:
  - Localize $@ when attempting to load URI subclasses (PR#30)
    Karen Etheridge:
  - speed up construction time by not attempting to load the same
    non-existent URI subclass twice
* Sat Jul 25 2015 coolo@suse.com
- updated to 1.69
  see /usr/share/doc/packages/perl-URI/Changes
  2015-07-25   Karen Etheridge <ether@cpan.org>
    Release 1.69
    Karen Etheridge:
  - add $VERSIONs for all modules that lack them
    Olaf Alders:
  - add missing documentation for URI::sftp
  - Clarify use of query_param() method
* Sat Jun 27 2015 coolo@suse.com
- updated to 1.68
  see /usr/share/doc/packages/perl-URI/Changes
  2015-06-25   Karen Etheridge <ether@cpan.org>
    Release 1.68
    Kent Fredric:
  - Sort hash keys to make generated query predictable
    Slaven Rezic:
  - Add new tests for path segments
    Brendan Byrd:
  - Add sftp scheme
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.67
  see /usr/share/doc/packages/perl-URI/Changes
  Revision history for URI
  2015-02-24   Karen Etheridge <ether@cpan.org>
    Release 1.67
    Karen Etheridge:
  - properly skip author test for normal user installs
  2015-02-24   Karen Etheridge <ether@cpan.org>
    Release 1.66
    Adam Herzog:
  - reorganize .pm files under lib/ (github #20)
  2014-11-05   Karen Etheridge <ether@cpan.org>
    Release 1.65
    Karen Etheridge:
  - add a TO_JSON method, to assist JSON serialization
  2014-07-13   Karen Etheridge <ether@cpan.org>
    Release 1.64
    Eric Brine:
  - better fix for RT#96941, that also works around utf8 bugs on older perls
  2014-07-13   Karen Etheridge <ether@cpan.org>
    Release 1.63
    Karen Etheridge:
  - mark utf8-related test failures on older perls caused by recent string
    parsing changes as TODO (RT#97177, RT#96941)
  2014-07-12   Karen Etheridge <ether@cpan.org>
    Release 1.62
    Karen Etheridge (2):
  - use strict and warnings in all modules, tests and scripts
  - remove all remaining uses of "use vars"
    Eric Brine:
  - fixed new "\C is deprecated in regex" warning in 5.21.2 (RT#96941)
  2014-07-01   Karen Etheridge <ether@cpan.org>
    Release 1.61
    David Schmidt:
    Fix test failure if local hostname is 'foo' [RT#75519]
    Gisle Aas (2):
    New 'has_recognized_scheme' interface [RT#71204]
    Interfaces that return a single value now return undef rather than an
    empty list in list context
    Slaven Rezic:
    Fix bad regex when parsing hostnames
    Piotr Roszatycki:
    Preferentially use $ENV{TMPDIR} for temporary test files over /tmp
    (fixes tests on Android)
* Sun Apr  1 2012 pascal.bleser@opensuse.org
- update to 1.60:
  * avoid failure if the local hostname is 'foo' [RT#75519]
  * fix RT#59274 - courtesy of a stupid 5.8.[12] join bug
* Fri Sep 16 2011 coolo@suse.com
- use original source URI
* Mon Aug 29 2011 vcizek@suse.com
- update to 1.59
  Make sure accessor methods don't return utf8::upgraded() bytes
  for URLs initialized from Unicode strings.
  Version number increments.
  Documentation tweaks.
* Mon Jan 24 2011 vcizek@novell.com
- update to 1.58
  This release reverts the patch in 1.57 that made query_form distingush
  between empty and undef values.  It broke stuff. [RT#62708]
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Nov 30 2010 coolo@novell.com
- do not use suggests on fedora
* Mon Nov 22 2010 anicka@suse.cz
- update to 1.56
  * Don't depend on DNS for the heuristics test
* Sat Sep  4 2010 chris@computersalat.de
- added bcond_with opt (for local build tests)
  o BuildRequires perl-Business-ISBN
* Sat Sep  4 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
- rpmlint
  o spurious-executable-perm uri-test
- removed obsolete patch
  o URI-1.37-path.diff
* Thu Sep  2 2010 pascal.bleser@opensuse.org
- update to 1.55:
  * Treat ? as a reserved character in file: URIs
    " is not a URI character [RT#56421]
  * Avoid test failure unless defined $Config{useperlio}
* Thu Apr  1 2010 anicka@suse.cz
- update to 1.54
  * Fix heuristic test fails on hosts in .su (or .uk) domains
* Fri Mar 26 2010 vuntz@opensuse.org
- Changes perl-Business-ISBN Recommends to Suggests:
  perl-Business-ISBN requires perl-GD-Barcode, and having this
  installed by default on minimal installs doesn't make sense,
  especially since it's big.
* Thu Mar 25 2010 anicka@suse.cz
- update to 1.53
  * Remove unneeded execute permissions.
  * Add $uri->secure() method.
  * Documentation and comment spelling fixes.
  * Fix heuristics when COUNTRY is set to "gb".
  * Use HTTP_ACCEPT_LANGUAGE, LC_ALL, and LANG in country heuristics.
  * POD linking improvements.
  * Rewrite the URI::Escape tests with Test::More
  * Update URI::Escape for RFC 3986
  * Bump MIN_PERL_VERSION to 5.6.1 [RT#54078]
  * Suppress wide caracters warnings in iri.t [RT#53737]
* Fri Jan 15 2010 anicka@suse.cz
- update to 1.52
  * Encode::decode('UTF-8',...) with callback implemented in 2.39
  * A "test case" to start IDNA prototype from
  * Escape IDNA hostnames
  * Introduce the as_unicode method
  * Make as_unicode undo punycode for server URLs
  * Hack to make as_iri turn A-labels into U-labels
  * Make as_iri leave escapes not forming valid UTF-8 sequences
  * Don't include RFCs in the cpan tarball
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Sep  7 2009 mls@suse.de
- break build cycle by removing perl-Business-ISBN BuildRequires
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sun Jun 28 2009 chris@computersalat.de
- update to 1.38
  * Spelling fixes.
  * skip DNS test if wildcard domain catcher (e.g. OpenDNS) is there
  * Avoid "Insecure $ENV{PATH} while running with -T switch" error with perl-5.6.
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o fixed deps
* Fri Jun 27 2008 anicka@suse.cz
- update to 1.37
  * Support ";" delimiter in $u->query_form
  * We get different test result when www.perl.com doesn't resolve.
  * URI::Heuristic didn't work for generic country code
* Wed Apr  9 2008 anicka@suse.cz
- update to 1.36
  * Escape Unicode strings as UTF-8.
  * fixed URL encoded data: URLs
  * uri_escape_utf8() now exported by default as documented.
  * Test fails with Business::ISBN installed
  * lc(undef) reports warning in blead
  * add some tests for gopher URIs
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Feb 17 2005 mjancar@suse.cz
- update to 1.35
* Wed Nov 24 2004 ro@suse.de
- disable remote connecting test
* Mon Sep 20 2004 ro@suse.de
- update to 1.33 to make it build again
* Fri Aug  6 2004 mjancar@suse.cz
- update to 1.31
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.30
* Thu Oct 30 2003 mjancar@suse.cz
- update to 1.27
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon Jun  9 2003 mjancar@suse.cz
- don't package MANIFEST
* Mon May 19 2003 ro@suse.de
- remove perllocal.pod
* Mon Apr 28 2003 mjancar@suse.cz
- update to version 1.23
* Thu Oct  3 2002 prehak@suse.cz
- updated to version 1.22
- removed perl-MIME-Base64 from neededforbuild
* Mon Jul 29 2002 mls@suse.de
- Fixed neededforbuild for perl-5.8.0
* Mon Jul 22 2002 prehak@suse.cz
- update to version 1.20
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Mon Jan 14 2002 rvasice@suse.cz
- update to version 1.18
* Wed Aug 15 2001 rvasice@suse.cz
- update to version 1.15
* Wed Mar 14 2001 cihlar@suse.cz
- update to version 1.11
* Tue Nov 14 2000 cihlar@suse.cz
- renamed perl_uri -> perl-URI
* Tue Aug 22 2000 cihlar@suse.cz
- update to 1.09
- bzipped sources
* Mon Aug 21 2000 ro@suse.de
- adapted for perl-5.6
* Fri Mar 31 2000 cihlar@suse.cz
- added BuildRoot
- added manpages to files
* Fri Mar 17 2000 ug@suse.de
- build for IMap Server CD
